==> moodle-1.5-mysql.tgz: moodle/lang/fi/exercise.php <==
<?PHP // $Id$ 
      // exercise.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005030501)


$string['absent'] = 'Puuttuva';
$string['accumulative'] = 'Kumulatiivinen';
$string['action'] = 'Toimenpide';
$string['ago'] = '$a sitten';
$string['amend'] = 'Muuta';
$string['amendassessmentelements'] = 'Muokkaa arvosteluperusteita';
$string['amendtitle'] = 'Muuta otsikko';
$string['analysis'] = 'Analyysi';
$string['assess'] = 'Arvioi';
$string['assessed'] = 'Arvioitu';
$string['assessment'] = 'Arviointi';
$string['assessmentby'] = 'Arvioinut $a';
$string['assessmentform'] = 'Arviointilomake';
$string['assessmentmadebythe'] = 'Arvioinnin tehnyt $a';
$string['assessmentofthissubmission'] = 'Tmn palautuksen arviointi';
$string['assessments'] = 'Arvioinnit';
$string['atthisstageyou'] = 'Tss vaiheessa olet suorittanut arvioinnin.<br />Haluat ehk tarkistaa tysi arvioinnin jlkeen.<br />Jos teet sen, muistathan tarkistaa mys arviointisi.<br />Voit tehd sen klikkaamalla alapuolella olevaa uudelleenarviointi-linkki.';
$string['awaitingassessmentbythe'] = 'Odottaa arviointia $a :lta';
$string['clearlateflag'] = 'Poista merkint myhstymisest';
$string['comment'] = 'Kommentti';
$string['comparisonofassessments'] = 'Arviointien vertailu';
$string['confirmdeletionofthisitem'] = 'Varmista $a :n poistaminen';
$string['correct'] = 'Oikein';
$string['count'] = 'Mr';
$string['criterion'] = 'Peruste';
$string['deadline'] = 'Mraika';
$string['deadlineis'] = 'Mraika on $a';
$string['delete'] = 'Poista';
$string['deletesubmissionwarning'] = 'Varoitus: $a:n arviontia liittliitettyn thn palautukseen.<br /> Suosittelemme vahvasti, ett tt palautusta EI poisteta.';
$string['deleting'] = 'Poistetaan';
$string['description'] = 'Kuvaus';
$string['descriptionofexercise'] = 'Oppimistehtvn tehtvkuvaus on Word-asiakirjassa tai HTML-tiedostossa. Tm tiedosto ladataan oppimistehtvn ennen kuin tehtv avautuu. On mys mahdollista tehd joukko muunnelmia samasta tehtvst lataamalla useampia Word- tai HTML-tiedostoja ennen tehtvn avautumista.';
$string['detailsofassessment'] = 'Arvioinnin yksityiskohdat';
$string['displayoffinalgrades'] = 'Lopullisten arvosanojen nytt';
$string['doubleupload'] = 'Varoitus: tm palautus on todennkisesti lhetetty  kahdesti. Mene yllpidon sivulle, etsi kahta palautusta tlt kyttjlt lyhyen ajan sisll. Poista ylimriset palautukset ennen jatkamista.';
$string['duedate'] = 'Erpiv';
$string['edit'] = 'Muokkaa';
$string['editingassessmentelements'] = 'Muokkataan arviointiperusteita';
$string['element'] = 'Arviointiperuste';
$string['elementweight'] = 'Arviointiperusteen painoarvo';
$string['enterpassword'] = 'Anna salasana';
$string['entriessaved'] = 'Tietueet tallennettu';
$string['errorbanded'] = 'Virheist vhentv';
$string['excellent'] = 'Erinomainen';
$string['exerciseassessments'] = 'Oppimistehtvn arvioinnit';
$string['exercisefeedback'] = 'Oppimistehtvn palaute';
$string['exercisesubmissions'] = 'Oppimistehtvn palautukset';
$string['fair'] = 'Tyydyttv';
$string['generalcomment'] = 'Yleinen kommentti';
$string['good'] = 'Hyv';
$string['gradeassessment'] = 'Arvostele arviointi';
$string['gradeforassessment'] = 'Arvosana arvioinnille';
$string['gradeforstudentsassessment'] = 'Arvosana $a arvioinnille';
$string['gradeforsubmission'] = 'Arvosana palautukselle';
$string['gradetable'] = 'Arvosanataulukko';
$string['gradinggrade'] = 'Arviointi asteikko';
$string['gradingstrategy'] = 'Arvostelun strategia';
$string['handlingofmultiplesubmissions'] = 'Useiden palautusten hallinta';
$string['hidenamesfromstudents'] = 'Piilota nimet oppilailta';
$string['incorrect'] = 'Virheellinen';
$string['late'] = 'Myhss';
$string['lax'] = 'Rento';
$string['leaguetable'] = 'Palautetut tyt';
$string['mail1'] = 'Palautuksesi \'$a\' on arvosteltu ';
$string['mail2'] = 'Kommentit ja arvosana nkyvt oppimistehtvn arvioinnissa $a';
$string['mail3'] = 'Voit nhd sen oppimistehtvn arvioinnissasi';
$string['mail6'] = 'Arviosi tehtvst \'$a\' on arvosteltu';
$string['mail7'] = '$a:n kommentit voit nhd oppimistehtvn arvioinnissa';
$string['managingassignment'] = 'Oppimistehtvn hallinta';
$string['maximum'] = 'Maksimi';
$string['maximumgradeforstudentassessments'] = 'Maksimi arvo opiskelijoiden arvioinneille: $a';
$string['maximumgradeforsubmissions'] = 'Maksimi arvo tehtville: $a';
$string['maximumsize'] = 'Suurin koko';
$string['mean'] = 'Keskiarvo';
$string['minimum'] = 'Minimi';
$string['modulename'] = 'Oppimistehtv';
$string['modulenameplural'] = 'Oppimistehtvt';
$string['movingtophase'] = 'Siirrytn vaiheeseen $a';
$string['multiplesubmissions'] = 'Useita palautuksia';
$string['noexercisedescriptionssubmitted'] = 'Oppimistehtvn kuvauksia ei ole mritelty';
$string['nosubmissions'] = 'Ei palautuksia';
$string['notassessedyet'] = 'Ei viel arvioitu';
$string['notavailable'] = 'Ei valittavissa';
$string['noteonassessmentelements'] = 'Huomaa, ett arvostelu on hajoitettu useisiin arvosteluperusteihin.<br />Tm helpottaa arvostelua ja tekee siit johdonmukaisemman. Opettajana sinun pit list nm osat ennen tehtvn julkistamista opiskelijoille.<br />Tm tehdn klikkaamalla kurssin tehtv, ja mikli arvosteluperusteita ei ole, sinua pyydetn lismn niit.<br />Voit muuttaa arvosteluperusteiden mr kytten tehtvn muokkaustilaa, itse arvosteluperusteita voi muokata \"Oppimistehtvn hallinta\"-ruudulta.';
$string['noteongradinggrade'] = 'Tm kertoo kuinka hyvin arvointisi sopii yhteen tyn $a arvioinnin kanssa. Korkeampi arvosana tarkoitaa parempaa yheensopivuutta.';
$string['noteonstudentassessments'] = '(Arvosana opiskelijalta/ Arvosanan arvosana opettajalta)';
$string['notgraded'] = 'Ei arvioitu';
$string['notitlegiven'] = 'Ei annettua otsikkoa';
$string['numberofassessmentelements'] = 'Kommenttien, arvosteluperusteiden, arvosanajoukkojen, perustelujen tai luokkien lukumr otsikossa';
$string['numberofcriterionelements'] = 'Perusteiden mrn pit ola enemmn kuin yksi.';
$string['numberofentries'] = 'Tietueiden mr';
$string['numberofentriesinleaguetable'] = 'Tietueden mr taulukossa';
$string['numberofnegativeresponses'] = 'Negatiivisten vastausten lukumr';
$string['onesubmission'] = 'Yksi palautus';
$string['optionaladjustment'] = 'Valinnainen tarkistus';
$string['overallgrade'] = 'Keskiarvo';
$string['passwordprotectedexercise'] = 'Salasana suojattu harjoitus';
$string['phase'] = 'Jakso';
$string['phase1'] = 'Laadi oppimistehtv';
$string['phase1short'] = 'Asetukset';
$string['phase2'] = 'Salli $a arviointia ja palautusta';
$string['phase2short'] = 'Avoin';
$string['phase3'] = 'Nyt kokonaisarvosanat ja palautukset vertailutaulukkona';
$string['phase3short'] = 'Asettelu';
$string['pleasegradetheassessment'] = 'Arvostele $a:n tyn arviointi';
$string['pleasemakeyourownassessment'] = 'Tee oma arviosi teoksesta $a:sta. <br /> Huomaa, ett arviokaavake on alkujaan nytetty oppilaiden arvioiden kanssa.<br /> Tee kaikki muutosehdotukset, joita oletat tarvitsevasi ja sen jlkeen klikkaa yhteen <br /> napeista, jotka ovat sivun alareunassa. ';
$string['pleasesubmityourwork'] = 'Palauta tysi kytten tt lomaketta';
$string['pleaseusethisform'] = 'Tyt tmn lomakkeen tiedot, kun olet <br />lukenut alla olevan oppimistehtvn ohjeet.';
$string['pleaseviewtheexercise'] = 'Katso oppimistehtv klikkaamalla sen otsikkoa.
<br />Seuraa tehtvn ohjeita.<br />Kun olet suorittanut tehtvn itsesi tyydyttvll tasolla, klikkaa Arvioi(tai Arvioi uudelleen)-linkki alla.<br /> Kun olet tehnyt arvioinnin, saat lisohjeita jatkotoimenpiteist.';
$string['poor'] = 'Heikkotasoinen';
$string['present'] = 'Nykyinen';
$string['reasonforadjustment'] = 'Tarkennuksen syy';
$string['reassess'] = 'Uudelleen arviointi';
$string['regradestudentassessments'] = 'Arvostele oppilas arviot uudelleen';
$string['resubmissionfor'] = '$a:n palautus uudelleen';
$string['resubmitnote'] = '* tarkoitaa, ett a$:lla on lupa palauttaa tm uudelleen.<br />Tm asetus voidaan antaa mille tahansa palautukselle arvioimalla se uudelleen ja klikkaamalla <br /><b>Salli $a:n uudelleenpalautukset</b>-painiketta. <br /Opiskelija voi palauttaa uudelleen, mikli tm asetus on <b>jossakin</b> heidn palautuksistaan.';
$string['rubric'] = 'Otsikko';
$string['savedok'] = 'Tallennettu';
$string['saveentries'] = 'Tallenna tietueet';
$string['savemyassessment'] = 'Tallenna arviointini';
$string['saveweights'] = 'Tallenna painoarvot';
$string['scale10'] = 'Pisteet kymmenest';
$string['scale100'] = 'Pisteet sadasta';
$string['scale20'] = 'Pisteet 20:st';
$string['scalecorrect'] = '2 pistett, asteikko Oikein/Vrin';
$string['scaleexcellent4'] = '4 pistett, asteikko Erinomainen/Erittin huono';
$string['scaleexcellent5'] = '5 pistett, asteikko Erinomainen/Erittin huono';
$string['scaleexcellent7'] = '7 pistett, asteikko Erinomainen/Erittin huono';
$string['scalegood3'] = '3 pistett, asteikko Hyv/Huono';
$string['scalepresent'] = '2 pistett, asteikko Osallistunut/Ei osallistunut';
$string['scaleyes'] = '2 pistett, asteikko Kyll/Ei';
$string['specimenassessmentform'] = 'Arvioinnin mallilomake';
$string['standarddeviation'] = 'Normipoikkeavuus';
$string['strict'] = 'tiukka';
$string['studentallowedtoresubmit'] = 'Salli $a:n uudelleenpalautukset';
$string['studentassessments'] = '$a arvostelut';
$string['studentnotallowed'] = '$a EI voi palauttaa uudelleen (tai palautusta ei tarvita)';
$string['studentsubmissions'] = '$a palautusta';
$string['studentsubmissionsforassessment'] = '$a opiskelijoiden palautusta arvioinnille';
$string['submission'] = 'Palautus';
$string['submissions'] = 'Palautukset';
$string['submissionsnowclosed'] = 'Palautusmahdollisuutta ei ole - viimeinen palautuspiv on ohitettu';
$string['submitexercisedescription'] = 'Aseta oppimistehtvn kuvaus';
$string['submitted'] = 'Toimitettu';
$string['submittedby'] = 'Toimittaja';
$string['suggestedgrade'] = 'Ehdotettu arvosana';
$string['teacherassessment'] = '$a arvostelu';
$string['teacherassessmenttable'] = '$a arvostelutaulukko';
$string['teacherscomment'] = 'Opettajan kommentti';
$string['theexercise'] = 'Oppimistehtv';
$string['theexerciseandthesubmissionby'] = 'Oppimistehtv ja $a:n palautus';
$string['thegradeis'] = 'Arvosana on $a';
$string['thereisfeedbackfromthe'] = 'Palautetta $a:lta';
$string['thisisaresubmission'] = 'Tm on a$:n palautus uudelleen.<br />Uuden palautuksen katsomisen jlkeen pivit tm arviointi<br />ja klikkaa yht sivun alalaidan painikkeista.';
$string['title'] = 'Otsikko';
$string['typeofscale'] = 'Asteikon tyyppi';
$string['unassessed'] = '$a arvioimatonta';
$string['ungradedstudentassessments'] = '$a arvioimatonta oppilasarviointia';
$string['usemaximum'] = 'Kyt suurinta';
$string['usemean'] = 'Kyt keskiarvoa';
$string['usepassword'] = 'kyt salasanaa';
$string['verylax'] = 'erittin rento';
$string['verypoor'] = 'Erittin heikkotasoinen';
$string['verystrict'] = 'erittin tiukka';
$string['view'] = 'Nyt';
$string['viewteacherassessment'] = 'Nyt $a :n arvio.';
$string['warningonamendingelements'] = 'VAROITUS: Palautettuja arviointeja ei ole. <br />L muuta arvosteluperusteiden mr, asteikkotyyppej tai arvosteluperusteiden painoarvoja.';
$string['weightederrorcount'] = 'Painotettu virheiden mr';
$string['weightforgradingofassessments'] = 'Arviointien arvostelun painoarvo';
$string['weightforteacherassessments'] = '$a arviointien painoarvo';
$string['weights'] = 'Painoarvot';
$string['weightssaved'] = 'Painoarvot tallennettu';
$string['weightsusedforoverallgrade'] = 'Kokonaisarvosanaa varten kytetyt painoarvot';
$string['wrongpassword'] = 'vr salasana tlle harjoitukselle';
$string['yourassessment'] = 'Sinun arviointisi';
$string['yourfeedbackgoeshere'] = 'Palautteesi tnne';
$string['yoursubmission'] = 'Palautuksesi';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/fi/exercise.php <==
<?PHP // $Id$ 
      // exercise.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005030501)


$string['absent'] = 'Puuttuva';
$string['accumulative'] = 'Kumulatiivinen';
$string['action'] = 'Toimenpide';
$string['ago'] = '$a sitten';
$string['amend'] = 'Muuta';
$string['amendassessmentelements'] = 'Muokkaa arvosteluperusteita';
$string['amendtitle'] = 'Muuta otsikko';
$string['analysis'] = 'Analyysi';
$string['assess'] = 'Arvioi';
$string['assessed'] = 'Arvioitu';
$string['assessment'] = 'Arviointi';
$string['assessmentby'] = 'Arvioinut $a';
$string['assessmentform'] = 'Arviointilomake';
$string['assessmentmadebythe'] = 'Arvioinnin tehnyt $a';
$string['assessmentofthissubmission'] = 'Tmn palautuksen arviointi';
$string['assessments'] = 'Arvioinnit';
$string['atthisstageyou'] = 'Tss vaiheessa olet suorittanut arvioinnin.<br />Haluat ehk tarkistaa tysi arvioinnin jlkeen.<br />Jos teet sen, muistathan tarkistaa mys arviointisi.<br />Voit tehd sen napsauttamalla alapuolella olevaa uudelleenarviointi-linkki.';
$string['awaitingassessmentbythe'] = 'Odottaa arviointia $a :lta';
$string['clearlateflag'] = 'Poista merkint myhstymisest';
$string['comment'] = 'Kommentti';
$string['comparisonofassessments'] = 'Arviointien vertailu';
$string['confirmdeletionofthisitem'] = 'Varmista $a :n poistaminen';
$string['correct'] = 'Oikein';
$string['count'] = 'Mr';
$string['criterion'] = 'Peruste';
$string['deadline'] = 'Mraika';
$string['deadlineis'] = 'Mraika on $a';
$string['delete'] = 'Poista';
$string['deletesubmissionwarning'] = 'Varoitus: $a:n arviontia liittliitettyn thn palautukseen.<br /> Suosittelemme vahvasti, ett tt palautusta EI poisteta.';
$string['deleting'] = 'Poistetaan';
$string['description'] = 'Kuvaus';
$string['descriptionofexercise'] = 'Oppimistehtvn tehtvkuvaus on Word-asiakirjassa tai HTML-tiedostossa. Tm tiedosto ladataan oppimistehtvn ennen kuin tehtv avautuu. On mys mahdollista tehd joukko muunnelmia samasta tehtvst lataamalla useampia Word- tai HTML-tiedostoja ennen tehtvn avautumista.';
$string['detailsofassessment'] = 'Arvioinnin yksityiskohdat';
$string['displayoffinalgrades'] = 'Lopullisten arvosanojen nytt';
$string['doubleupload'] = 'Varoitus: tm palautus on todennkisesti lhetetty  kahdesti. Mene yllpidon sivulle, etsi kahta palautusta tlt kyttjlt lyhyen ajan sisll. Poista ylimriset palautukset ennen jatkamista.';
$string['duedate'] = 'Erpiv';
$string['edit'] = 'Muokkaa';
$string['editingassessmentelements'] = 'Muokkataan arviointiperusteita';
$string['element'] = 'Arviointiperuste';
$string['elementweight'] = 'Arviointiperusteen painoarvo';
$string['enterpassword'] = 'Anna salasana';
$string['entriessaved'] = 'Tietueet tallennettu';
$string['errorbanded'] = 'Virheist vhentv';
$string['excellent'] = 'Erinomainen';
$string['exerciseassessments'] = 'Oppimistehtvn arvioinnit';
$string['exercisefeedback'] = 'Oppimistehtvn palaute';
$string['exercisesubmissions'] = 'Oppimistehtvn palautukset';
$string['fair'] = 'Tyydyttv';
$string['generalcomment'] = 'Yleinen kommentti';
$string['good'] = 'Hyv';
$string['gradeassessment'] = 'Arvostele arviointi';
$string['gradeforassessment'] = 'Arvosana arvioinnille';
$string['gradeforstudentsassessment'] = 'Arvosana $a arvioinnille';
$string['gradeforsubmission'] = 'Arvosana palautukselle';
$string['gradetable'] = 'Arvosanataulukko';
$string['gradinggrade'] = 'Arviointi asteikko';
$string['gradingstrategy'] = 'Arvostelun strategia';
$string['handlingofmultiplesubmissions'] = 'Useiden palautusten hallinta';
$string['hidenamesfromstudents'] = 'Piilota nimet oppilailta';
$string['incorrect'] = 'Virheellinen';
$string['late'] = 'Myhss';
$string['lax'] = 'Rento';
$string['leaguetable'] = 'Palautetut tyt';
$string['mail1'] = 'Palautuksesi \'$a\' on arvosteltu ';
$string['mail2'] = 'Kommentit ja arvosana nkyvt oppimistehtvn arvioinnissa $a';
$string['mail3'] = 'Voit nhd sen oppimistehtvn arvioinnissasi';
$string['mail6'] = 'Arviosi tehtvst \'$a\' on arvosteltu';
$string['mail7'] = '$a:n kommentit voit nhd oppimistehtvn arvioinnissa';
$string['managingassignment'] = 'Oppimistehtvn hallinta';
$string['maximum'] = 'Maksimi';
$string['maximumgradeforstudentassessments'] = 'Maksimi arvo opiskelijoiden arvioinneille: $a';
$string['maximumgradeforsubmissions'] = 'Maksimi arvo tehtville: $a';
$string['maximumsize'] = 'Suurin koko';
$string['mean'] = 'Keskiarvo';
$string['minimum'] = 'Minimi';
$string['modulename'] = 'Oppimistehtv';
$string['modulenameplural'] = 'Oppimistehtvt';
$string['movingtophase'] = 'Siirrytn vaiheeseen $a';
$string['multiplesubmissions'] = 'Useita palautuksia';
$string['noexercisedescriptionssubmitted'] = 'Oppimistehtvn kuvauksia ei ole mritelty';
$string['nosubmissions'] = 'Ei palautuksia';
$string['notassessedyet'] = 'Ei viel arvioitu';
$string['notavailable'] = 'Ei valittavissa';
$string['noteonassessmentelements'] = 'Huomaa, ett arvostelu on hajoitettu useisiin arvosteluperusteihin.<br />Tm helpottaa arvostelua ja tekee siit johdonmukaisemman. Opettajana sinun pit list nm osat ennen tehtvn julkistamista opiskelijoille.<br />Tm tehdn napsauttamalla kurssin tehtv, ja mikli arvosteluperusteita ei ole, sinua pyydetn lismn niit.<br />Voit muuttaa arvosteluperusteiden mr kytten tehtvn muokkaustilaa, itse arvosteluperusteita voi muokata \"Oppimistehtvn hallinta\"-ruudulta.';
$string['noteongradinggrade'] = 'Tm kertoo kuinka hyvin arvointisi sopii yhteen tyn $a arvioinnin kanssa. Korkeampi arvosana tarkoitaa parempaa yheensopivuutta.';
$string['noteonstudentassessments'] = '(Arvosana opiskelijalta/ Arvosanan arvosana opettajalta)';
$string['notgraded'] = 'Ei arvioitu';
$string['notitlegiven'] = 'Ei annettua otsikkoa';
$string['numberofassessmentelements'] = 'Kommenttien, arvosteluperusteiden, arvosanajoukkojen, perustelujen tai luokkien lukumr otsikossa';
$string['numberofcriterionelements'] = 'Perusteiden mrn pit ola enemmn kuin yksi.';
$string['numberofentries'] = 'Tietueiden mr';
$string['numberofentriesinleaguetable'] = 'Tietueden mr taulukossa';
$string['numberofnegativeresponses'] = 'Negatiivisten vastausten lukumr';
$string['onesubmission'] = 'Yksi palautus';
$string['optionaladjustment'] = 'Valinnainen tarkistus';
$string['overallgrade'] = 'Keskiarvo';
$string['passwordprotectedexercise'] = 'Salasana suojattu harjoitus';
$string['phase'] = 'Jakso';
$string['phase1'] = 'Laadi oppimistehtv';
$string['phase1short'] = 'Asetukset';
$string['phase2'] = 'Salli $a arviointia ja palautusta';
$string['phase2short'] = 'Avoin';
$string['phase3'] = 'Nyt kokonaisarvosanat ja palautukset vertailutaulukkona';
$string['phase3short'] = 'Asettelu';
$string['pleasegradetheassessment'] = 'Arvostele $a:n tyn arviointi';
$string['pleasemakeyourownassessment'] = 'Tee oma arviosi teoksesta $a:sta. <br /> Huomaa, ett arviokaavake on alkujaan nytetty oppilaiden arvioiden kanssa.<br /> Tee kaikki muutosehdotukset, joita oletat tarvitsevasi ja sen jlkeen napsauta yhteen <br /> napeista, jotka ovat sivun alareunassa. ';
$string['pleasesubmityourwork'] = 'Palauta tysi kytten tt lomaketta';
$string['pleaseusethisform'] = 'Tyt tmn lomakkeen tiedot, kun olet <br />lukenut alla olevan oppimistehtvn ohjeet.';
$string['pleaseviewtheexercise'] = 'Katso oppimistehtv napsauttamalla sen otsikkoa.
<br />Seuraa tehtvn ohjeita.<br />Kun olet suorittanut tehtvn itsesi tyydyttvll tasolla, napsauta Arvioi(tai Arvioi uudelleen)-linkki alla.<br /> Kun olet tehnyt arvioinnin, saat lisohjeita jatkotoimenpiteist.';
$string['poor'] = 'Heikkotasoinen';
$string['present'] = 'Nykyinen';
$string['reasonforadjustment'] = 'Tarkennuksen syy';
$string['reassess'] = 'Uudelleen arviointi';
$string['regradestudentassessments'] = 'Arvostele oppilas arviot uudelleen';
$string['resubmissionfor'] = '$a:n palautus uudelleen';
$string['resubmitnote'] = '* tarkoitaa, ett a$:lla on lupa palauttaa tm uudelleen.<br />Tm asetus voidaan antaa mille tahansa palautukselle arvioimalla se uudelleen ja napsauta <br /><b>Salli $a:n uudelleenpalautukset</b>-painiketta. <br /Opiskelija voi palauttaa uudelleen, mikli tm asetus on <b>jossakin</b> heidn palautuksistaan.';
$string['rubric'] = 'Otsikko';
$string['savedok'] = 'Tallennettu';
$string['saveentries'] = 'Tallenna tietueet';
$string['savemyassessment'] = 'Tallenna arviointini';
$string['saveweights'] = 'Tallenna painoarvot';
$string['scale10'] = 'Pisteet kymmenest';
$string['scale100'] = 'Pisteet sadasta';
$string['scale20'] = 'Pisteet 20:st';
$string['scalecorrect'] = '2 pistett, asteikko Oikein/Vrin';
$string['scaleexcellent4'] = '4 pistett, asteikko Erinomainen/Erittin huono';
$string['scaleexcellent5'] = '5 pistett, asteikko Erinomainen/Erittin huono';
$string['scaleexcellent7'] = '7 pistett, asteikko Erinomainen/Erittin huono';
$string['scalegood3'] = '3 pistett, asteikko Hyv/Huono';
$string['scalepresent'] = '2 pistett, asteikko Osallistunut/Ei osallistunut';
$string['scaleyes'] = '2 pistett, asteikko Kyll/Ei';
$string['specimenassessmentform'] = 'Arvioinnin mallilomake';
$string['standarddeviation'] = 'Normipoikkeavuus';
$string['strict'] = 'tiukka';
$string['studentallowedtoresubmit'] = 'Salli $a:n uudelleenpalautukset';
$string['studentassessments'] = '$a arvostelut';
$string['studentnotallowed'] = '$a EI voi palauttaa uudelleen (tai palautusta ei tarvita)';
$string['studentsubmissions'] = '$a palautusta';
$string['studentsubmissionsforassessment'] = '$a opiskelijoiden palautusta arvioinnille';
$string['submission'] = 'Palautus';
$string['submissions'] = 'Palautukset';
$string['submissionsnowclosed'] = 'Palautusmahdollisuutta ei ole - viimeinen palautuspiv on ohitettu';
$string['submitexercisedescription'] = 'Aseta oppimistehtvn kuvaus';
$string['submitted'] = 'Toimitettu';
$string['submittedby'] = 'Toimittaja';
$string['suggestedgrade'] = 'Ehdotettu arvosana';
$string['teacherassessment'] = '$a arvostelu';
$string['teacherassessmenttable'] = '$a arvostelutaulukko';
$string['teacherscomment'] = 'Opettajan kommentti';
$string['theexercise'] = 'Oppimistehtv';
$string['theexerciseandthesubmissionby'] = 'Oppimistehtv ja $a:n palautus';
$string['thegradeis'] = 'Arvosana on $a';
$string['thereisfeedbackfromthe'] = 'Palautetta $a:lta';
$string['thisisaresubmission'] = 'Tm on a$:n palautus uudelleen.<br />Uuden palautuksen katsomisen jlkeen pivit tm arviointi<br />ja napsauta yht sivun alalaidan painikkeista.';
$string['title'] = 'Otsikko';
$string['typeofscale'] = 'Asteikon tyyppi';
$string['unassessed'] = '$a arvioimatonta';
$string['ungradedstudentassessments'] = '$a arvioimatonta oppilasarviointia';
$string['usemaximum'] = 'Kyt suurinta';
$string['usemean'] = 'Kyt keskiarvoa';
$string['usepassword'] = 'kyt salasanaa';
$string['verylax'] = 'erittin rento';
$string['verypoor'] = 'Erittin heikkotasoinen';
$string['verystrict'] = 'erittin tiukka';
$string['view'] = 'Nyt';
$string['viewteacherassessment'] = 'Nyt $a :n arvio.';
$string['warningonamendingelements'] = 'VAROITUS: Palautettuja arviointeja ei ole. <br />L muuta arvosteluperusteiden mr, asteikkotyyppej tai arvosteluperusteiden painoarvoja.';
$string['weightederrorcount'] = 'Painotettu virheiden mr';
$string['weightforgradingofassessments'] = 'Arviointien arvostelun painoarvo';
$string['weightforteacherassessments'] = '$a arviointien painoarvo';
$string['weights'] = 'Painoarvot';
$string['weightssaved'] = 'Painoarvot tallennettu';
$string['weightsusedforoverallgrade'] = 'Kokonaisarvosanaa varten kytetyt painoarvot';
$string['wrongpassword'] = 'vr salasana tlle harjoitukselle';
$string['yourassessment'] = 'Sinun arviointisi';
$string['yourfeedbackgoeshere'] = 'Palautteesi tnne';
$string['yoursubmission'] = 'Palautuksesi';

?>
